@@ -13,11 +13,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
- squidview 0.7x
+ squidview 0.8x
  
  A program to nicely browse your squid log
   
- (c) 2001 - 2007 Graeme Sheppard
+ (c) 2001 - 2013 Graeme Sheppard
 
  */
 
@@ -40,16 +40,13 @@ using namespace std;
 #define nInputLen 80
 #define nReadBuffer 2048
 
-#define nTimeCol 1      // fields/columns of squid log lines 
-#define nCacheHitCol 4
-#define nSizeCol 5
-#define nTargetCol 7
-#define nUserCol_a 8
-#define nIPCol_a 3
-#define nUserCol_b 3
-#define nIPCol_b 3
-int iUserCol = nUserCol_a;
-int iIPCol = nIPCol_a;
+// fields/columns of squid log lines 
+int iTimeCol = -1;
+int iCacheHitCol = -1;
+int iSizeCol = -1;
+int iTargetCol = -1;
+int iUserCol = -1;
+int iIPCol = -1;
 
 int iUserNameLen = 8;  // maximum displayed width of a login name
 #define nSizeCols 11   // width given to display size of requests
